@@ -15,9 +15,9 @@ class OpenLeap():
     #Dataclass that describes position and other values of each hand
     @dataclass
     class Data:
-        x : int = 0
-        y : int = 0
-        z : int = 0
+        x : float = 0
+        y : float = 0
+        z : float = 0
         distance: float = 0.0
         angle: float = 0.0
         gesture: str = None
@@ -26,7 +26,8 @@ class OpenLeap():
                 SCREEN_SHOW=False, 
                 SCREEN_TYPE='BLACK', 
                 SHOW_DATA_IN_CONSOLE=False, 
-                SHOW_DATA_ON_IMAGE=False
+                SHOW_DATA_ON_IMAGE=False, 
+                NORMALIZED_POSITION=True, 
         ):
 
         super().__init__()
@@ -51,6 +52,8 @@ class OpenLeap():
         self.SHOW_DATA_IN_CONSOLE=SHOW_DATA_IN_CONSOLE
         self.SHOW_DATA_ON_IMAGE=SHOW_DATA_ON_IMAGE
 
+        self.NORMALIZED_POSITION=NORMALIZED_POSITION
+
         #CONSTANTS
         self.WIDTH = int(self.cap.get(cv2.CAP_PROP_FRAME_WIDTH))
         self.HEIGHT = int(self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
@@ -59,7 +62,7 @@ class OpenLeap():
         #MediaPipe
         self.mp_drawing = mp.solutions.drawing_utils
         self.mp_hands = mp.solutions.hands
-        self.hands = self.mp_hands.Hands(min_detection_confidence=0.8, min_tracking_confidence=0.5)
+        self.hands = self.mp_hands.Hands(min_detection_confidence=0.5, min_tracking_confidence=0.3)
         self.results = None
 
 
@@ -117,7 +120,7 @@ class OpenLeap():
         return label
 
 
-    def get_position(self, index=0, landmark_idx=1, dim=None):
+    def get_position(self, index=0, landmark_idx=1, normalized=False):
         """
         Finds normalized position or of given hand landmark. Additionally, it can calculate the position on the screen
         if dimensions are give. 
@@ -132,13 +135,13 @@ class OpenLeap():
         y = self.results.multi_hand_landmarks[index].landmark[landmark_idx].y
         z = self.results.multi_hand_landmarks[index].landmark[landmark_idx].y
 
-        if dim is None:
+        if normalized:
             #Choose proper index instead of fixed one (idx=0)
             return x, y, z
         else:
-            x = int(x*dim[0])
-            y = int(y*dim[1])
-            z = int(z*dim[0])
+            x = int(x*self.WIDTH)
+            y = int(y*self.HEIGHT)
+            z = int(z*self.WIDTH)
 
         return x, y, z
 
@@ -155,15 +158,12 @@ class OpenLeap():
 
         returns: float
         """
-
-        x1, y1, z1 = self.get_position(index, landmark_1, self.DIMENSIONS)
-        x2, y2, z2 = self.get_position(index, landmark_2, self.DIMENSIONS)
-
-        x1 *= self.WIDTH
-        x2 *= self.WIDTH
-
-        y1 *= self.HEIGHT
-        y2 *= self.HEIGHT
+        if normalized:
+            x1, y1, z1 = self.get_position(index, landmark_1, normalized=True)
+            x2, y2, z2 = self.get_position(index, landmark_2, normalized=True)
+        else:
+            x1, y1, z1 = self.get_position(index, landmark_1)
+            x2, y2, z2 = self.get_position(index, landmark_2)
 
         distance = math.sqrt(((x1-x2)**2 + (y1-y2)**2))
 
@@ -210,7 +210,7 @@ class OpenLeap():
 
         if console:
             for index, (key, d) in enumerate(self.data.items()):
-                print('%s hand:\tX=%d,\tY=%d,\tZ=%d,\tdistance=%.2f,\tangle=%f,\tgesture="%s"' %(key.capitalize(), d.x, d.y, d.z, d.distance, d.angle, d.gesture))
+                print('%s hand:\tX=%f,\tY=%f,\tZ=%f,\tdistance=%.2f,\tangle=%f,\tgesture="%s"' %(key.capitalize(), d.x, d.y, d.z, d.distance, d.angle, d.gesture))
 
         
         if on_image:
@@ -293,7 +293,7 @@ class OpenLeap():
                         #If there are two hands
                         if self.left_or_right(index, hand, 'position'):
                             hand_type = self.left_or_right(index, hand, 'position')
-                            x, y, z = self.get_position(index, self.mp_hands.HandLandmark.WRIST, self.DIMENSIONS)
+                            x, y, z = self.get_position(index, self.mp_hands.HandLandmark.WRIST, normalized=self.NORMALIZED_POSITION)
 
                             self.data[hand_type].x = x
                             self.data[hand_type].y = y
@@ -309,8 +309,8 @@ class OpenLeap():
 
                             if self.SCREEN_SHOW:
 
-                                x1, y1, z1 = self.get_position(index, self.mp_hands.HandLandmark.INDEX_FINGER_TIP, self.DIMENSIONS)
-                                x2, y2, z2 = self.get_position(index, self.mp_hands.HandLandmark.THUMB_TIP, self.DIMENSIONS)
+                                x1, y1, z1 = self.get_position(index, self.mp_hands.HandLandmark.INDEX_FINGER_TIP, normalized= not self.NORMALIZED_POSITION)
+                                x2, y2, z2 = self.get_position(index, self.mp_hands.HandLandmark.THUMB_TIP, normalized= not self.NORMALIZED_POSITION)
 
                                 #Draw line that connects index finger tip and thumb tip
                                 cv2.line(background, (x1, y1), (x2, y2), (255, 125, 100), 2)
@@ -321,6 +321,7 @@ class OpenLeap():
                                 
                                 if self.SHOW_DATA_ON_IMAGE:
                                     #Show on screen
+                                    x, y, z = self.get_position(index, self.mp_hands.HandLandmark.WRIST, normalized= not self.NORMALIZED_POSITION)
                                     cv2.putText(background, hand_type, (x,y), cv2.FONT_HERSHEY_SIMPLEX, 1, (255, 0, 0), 2, cv2.LINE_AA)
 
                                 self.show_data(background, console=self.SHOW_DATA_IN_CONSOLE, on_image=self.SHOW_DATA_ON_IMAGE)
@@ -348,7 +349,7 @@ if __name__=='__main__':
     Use example of OpenLeap object. 
     '''
 
-    controller = OpenLeap(SHOW_DATA_IN_CONSOLE=True)
+    controller = OpenLeap(SHOW_DATA_IN_CONSOLE=True, SCREEN_SHOW=True, SCREEN_TYPE='CAM', SHOW_DATA_ON_IMAGE=True)
 
     while True:
         controller.main()
